@@ -4,7 +4,7 @@ DragWidget::DragWidget(QWidget *parent, const char *name, WFlags f) : QWidget(pa
 {
 	dragP=QPoint(0,0);
 	drag=false;
-
+	locked=false;
 }
 DragWidget::~DragWidget()
 {
@@ -13,8 +13,10 @@ DragWidget::~DragWidget()
 
 void DragWidget::mousePressEvent(QMouseEvent *e)
 {
+	
 	dragP=e->pos();
 	gpress=e->globalPos();
+	if (locked)return;
 	drag=true;
 
 }
@@ -33,3 +35,14 @@ void DragWidget::mouseMoveEvent(QMouseEvent *e)
 	
 }
 
+void DragWidget::setLocked(bool mode)
+{
+	locked=mode;
+}
+
+const bool DragWidget::isLocked() const
+{
+	return locked;
+}
+
+
