@@ -11,9 +11,13 @@ public:
 	DragWidget(QWidget *parent=0, const char *name="", WFlags f=0);
 	virtual ~DragWidget();
 
+	void setLocked(bool mode);
+	const bool isLocked() const;
+
 private:
 	
 	bool drag;
+	
 
 protected:
 	void mouseMoveEvent ( QMouseEvent * e );
@@ -21,6 +25,7 @@ protected:
 	void mouseReleaseEvent ( QMouseEvent * e );
 	QPoint dragP;
 	QPoint gpress;
+	bool locked;
 
 };
 
