@@ -44,7 +44,9 @@
 
 bool shutting=false;
 
-MainWidget::MainWidget ( KAboutData *about, bool tren, QWidget *parent, const char * name, WFlags f ) : ResizableDragWidget ( parent,name,f ), stand_alone(tren)
+VButton *global_shift;
+
+MainWidget::MainWidget ( KAboutData *about, bool tren, QWidget *parent, const char * name, WFlags f ) : ResizableDragWidget ( parent,name,f ), dock(0), stand_alone(tren)
 {
 
 	
@@ -115,7 +117,7 @@ MainWidget::MainWidget ( KAboutData *about, bool tren, QWidget *parent, const ch
 		f->move ( stx+esc->width() + ( 35*a ) +45+ ( 8*35 ) +10,sty );
 		f->res();
 		other_keys.append(f);
-		connect ( f,SIGNAL ( keyClick ( unsigned int ) ), this, SLOT ( keyPress ( unsigned int ) ) );
+		connect ( f, SIGNAL ( keyClick ( unsigned int ) ), this, SLOT ( keyPress ( unsigned int ) ) );
 	}
 
 	//ROW 1
@@ -249,6 +251,7 @@ MainWidget::MainWidget ( KAboutData *about, bool tren, QWidget *parent, const ch
 	connect ( lshft,SIGNAL ( keyClick ( unsigned int ) ), this, SLOT ( toggleShift() ) );
 	mod_keys.append ( lshft );
 	lshft->res();
+	global_shift=lshft;
 
 	for ( int a=0;a<R4LEN;a++ )
 	{
@@ -518,6 +521,11 @@ MainWidget::MainWidget ( KAboutData *about, bool tren, QWidget *parent, const ch
 		m->insertSeparator();
 		m->insertItem ( "Help", h->menu() );
 		
+		mnu_lock = m->insertItem("Lock on screen", this, SLOT(toggleLock()));
+		bool is_locked = cfg->readBoolEntry("locked",false);
+		m->setItemChecked(mnu_lock,is_locked);
+
+
 		tray->show();
 		
 		dock = new KbdDock ( this );
@@ -726,6 +734,18 @@ void MainWidget::quitClicked()
 	else
 		hide();
 }
+void MainWidget::toggleLock()
+{
+	bool c = isLocked();
+
+	tray->contextMenu()->setItemChecked ( mnu_lock, !c );
+	setLocked(!c);
+
+	KConfig *cfg = KApplication::kApplication()->config();
+	cfg->writeEntry ("locked", !c);
+	cfg->sync();
+
+}
 void MainWidget::showDock()
 {
 	bool c = dock->isShown();
@@ -798,12 +818,12 @@ void MainWidget::keyPress ( unsigned int a )
 				v->capsPressed(true);
 			}
 		}
-	}else {
-            for (unsigned a=0;a<btns.size();a++)
-            {
-                    VButton *v = ( VButton* ) btns[a];
-                    v->capsPressed(false);
-            }
+	}
+	else {
+		for (unsigned a=0;a<btns.size();a++) {
+			VButton *v = ( VButton* ) btns[a];
+			v->capsPressed(false);
+		}
 	}
 
 }
@@ -1835,3 +1855,13 @@ void KbdTray::mousePressEvent(QMouseEvent *e)
 
 
 
+
+
+KbdDock * MainWidget::kbdDock() const
+{
+	return dock;
+}
+
+
+
+
