@@ -46,6 +46,7 @@ public:
 	void mappingNotify(XMappingEvent *e);
 	void finishInit();
 	bool close ( bool alsoDelete );
+	KbdDock* kbdDock() const;
 
 public slots:
 	void keyPress(unsigned int keycode);
@@ -66,6 +67,7 @@ public slots:
 	void showConfigMenu();
 // 	void shutDown();
  	void saveState();
+	void toggleLock();
 
 protected:
 	void resizeEvent(QResizeEvent *e);
@@ -127,6 +129,7 @@ private:
 	double sdxb;
 	int mnu_dock;
 	int mnu_autores;
+	int mnu_lock;
 
 };
 
