@@ -23,7 +23,7 @@ public:
 	static double ph;
 
 private:
-	bool press;
+	int press;
 	bool inrpt;
 
 protected:
