@@ -35,7 +35,7 @@
 static const char description[] =
     I18N_NOOP("A virtual keyboard for KDE");
 
-static const char version[] = "0.4.8";
+static const char version[] = "0.5";
 
 static KCmdLineOptions options[] =
 {
@@ -107,6 +107,9 @@ public:
 		c << "show()";
 		c << "hide()";
 		c << "state()";
+		c << "dockw_show()";
+		c << "dockw_hide()";
+		c << "dockw_state()";
 		return c;
 	}
 	bool process(const QCString &fun, const QByteArray &data,
@@ -117,6 +120,7 @@ public:
 		replyType="QCString";	
 		MainWidget *main = (MainWidget *)mainWidget();
 		if (main) {
+			KbdDock *dock = main->kbdDock();
 			if (fun == "show()") {
 				main->show();
 				io<<"Success";
@@ -131,6 +135,36 @@ public:
 				io << (main->isShown()?"visible":"hidden");
 				return true;	
 			} 
+			else if (fun == "dockw_state()"){
+				
+				if (dock) {
+					io << (dock->isShown()?"visible":"hidden");
+				}
+				else {
+					io<<"no dock";
+				}
+				return true;	
+			}
+			else if (fun == "dockw_hide()"){
+				if (dock){
+					dock->hide();
+					io<<"Success";
+				}
+				else {
+					io<<"no dock";
+				}
+				return true;	
+			}
+			else if (fun == "dockw_show()"){
+				if (dock){
+					dock->show();
+					io<<"Success";
+				}
+				else {
+					io<<"no dock";
+				}
+				return true;	
+			}
 		}
 		
 		return KUniqueApplication::process(fun,data,replyType,replyData);
